======
Pickle
======

The one true Pickler, it takes the pickle and encodes the bits and a space
and a pickle emoji.

Installation
============
From PyPi::

    $ pip install piickle

Basic Usage
===========
.. code-block:: python

    import piickle

    Pickle.dump(object, file) # Same as the python pickle.dump()
    Pickle.dumps(object) # Same as the python pickle.dumps()
    Pickle.load(file) # Same as the python pickle.load()
    Pickle.loads(object) # Same as the python pickle.loads()

Features
========
* A truly horrible pun
